# Table of Contents

- [provisioning-sap-leanix-workspace](<./provisioning-sap-leanix-workspace.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Provisioning SAP LeanIX from SAP for Me (NGCS)](<./Provisioning-SAP-LeanIX-from-SAP-for-Me-NGCS.md>)
  - [Prerequisites](<./Provisioning-SAP-LeanIX-from-SAP-for-Me-NGCS/Prerequisites.md>)
  - [Context](<./Provisioning-SAP-LeanIX-from-SAP-for-Me-NGCS/Context.md>)
  - [Procedure](<./Provisioning-SAP-LeanIX-from-SAP-for-Me-NGCS/Procedure.md>)
